diff options
| author | 2012-07-02 17:59:33 +0900 | |
|---|---|---|
| committer | 2012-07-18 16:55:04 -0300 | |
| commit | bcd3ef58283a471d6b65855b83f78bd39eb55391 (patch) | |
| tree | d8814c9fbf17570a1cbed823b2dea7468fe9c1d9 /include/linux | |
| parent | KVM: MMU: Push trace_kvm_age_page() into kvm_age_rmapp() (diff) | |
KVM: MMU: Avoid handling same rmap_pde in kvm_handle_hva_range()
When we invalidate a THP page, we call the handler with the same
rmap_pde argument 512 times in the following loop:
for each guest page in the range
for each level
unmap using rmap
This patch avoids these extra handler calls by changing the loop order
like this:
for each level
for each rmap in the range
unmap using rmap
With the preceding patches in the patch series, this made THP page
invalidation more than 5 times faster on our x86 host: the host became
more responsive during swapping the guest's memory as a result.
Signed-off-by: Takuya Yoshikawa <yoshikawa.takuya@oss.ntt.co.jp>
Signed-off-by: Marcelo Tosatti <mtosatti@redhat.com>
Diffstat (limited to 'include/linux')
0 files changed, 0 insertions, 0 deletions
